@@ -4,6 +4,7 @@ import math
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union, cast
 
 from pfzy import fuzzy_match
+from pfzy.score import fzy_scorer, substr_scorer
 from pfzy.types import HAYSTACKS
 from prompt_toolkit.application.application import Application
 from prompt_toolkit.buffer import Buffer
@@ -63,12 +64,14 @@ class InquirerPyFuzzyControl(InquirerPyUIListControl):
         session_result: Optional[InquirerPySessionResult],
         multiselect: bool,
         marker_pl: str,
+        match_exact: bool,
     ) -> None:
         self._pointer = pointer
         self._marker = marker
         self._marker_pl = marker_pl
         self._current_text = current_text
         self._max_lines = max_lines if max_lines > 0 else 1
+        self._scorer = fzy_scorer if not match_exact else substr_scorer
         super().__init__(
             choices=choices,
             default=None,
@@ -219,6 +222,7 @@ class InquirerPyFuzzyControl(InquirerPyUIListControl):
                 self._current_text(),
                 cast(HAYSTACKS, self.choices),
                 key="name",
+                scorer=self._scorer,
             )
         return choices
 
@@ -287,7 +291,9 @@ class FuzzyPrompt(BaseListPrompt):
             Setting to True will also change the result from a single value to a list of values.
         prompt: Input prompt symbol. Custom symbol to display infront of the input buffer to indicate for input.
         border: Create border around the choice window.
-        info: Display choice information similar to fzf --info=inline next tot he prompt.
+        info: Display choice information similar to fzf --info=inline next to the prompt.
+        match_exact: Use exact sub-string match instead of using fzy fuzzy match algorithm.
+        exact_symbol: Custom symbol to display in the info section when `info=True`.
         marker: Marker Symbol. Custom symbol to indicate if a choice is selected.
             This will take effects when `multiselect` is True.
         marker_pl: Marker place holder when the choice is not selected.
@@ -329,6 +335,8 @@ class FuzzyPrompt(BaseListPrompt):
         marker_pl: str = " ",
         border: bool = False,
         info: bool = True,
+        match_exact: bool = False,
+        exact_symbol: str = " E",
         height: Union[str, int] = None,
         max_height: Union[str, int] = None,
         validate: InquirerPyValidate = None,
@@ -347,11 +355,13 @@ class FuzzyPrompt(BaseListPrompt):
         self._info = info
         self._task = None
         self._rendered = False
+        self._exact_symbol = exact_symbol
 
         keybindings = {
             "up": [{"key": "up"}, {"key": "c-p"}],
             "down": [{"key": "down"}, {"key": "c-n"}],
             "toggle": [],
+            "toggle-exact": [],
             **keybindings,
         }
         super().__init__(
@@ -376,6 +386,7 @@ class FuzzyPrompt(BaseListPrompt):
             mandatory_message=mandatory_message,
             session_result=session_result,
         )
+        self.kb_func_lookup = {"toggle-exact": [{"func": self._toggle_exact}]}
         self._default = (
             default
             if not isinstance(default, Callable)
@@ -395,6 +406,7 @@ class FuzzyPrompt(BaseListPrompt):
             session_result=session_result,
             multiselect=multiselect,
             marker_pl=marker_pl,
+            match_exact=match_exact,
         )
 
         self._buffer = Buffer(on_text_changed=self._on_text_changed)
@@ -470,6 +482,23 @@ class FuzzyPrompt(BaseListPrompt):
             after_render=self._after_render,
         )
 
+    def _toggle_exact(self, _, value: bool = None) -> None:
+        """Toggle matching algorithm.
+
+        Switch between fzy fuzzy match or sub-string exact match.
+
+        Args:
+            value: Specify the value to toggle.
+        """
+        if value is not None:
+            self.content_control._scorer = fzy_scorer if not value else substr_scorer
+        else:
+            self.content_control._scorer = (
+                fzy_scorer
+                if self.content_control._scorer == substr_scorer
+                else substr_scorer
+            )
+
     def _on_rendered(self, _) -> None:
         """Render callable choices and set the buffer default text.
 
@@ -503,17 +532,15 @@ class FuzzyPrompt(BaseListPrompt):
             display_message.append(
                 (
                     "class:fuzzy_info",
-                    "%s/%s"
-                    % (
-                        self.content_control.choice_count,
-                        len(self.content_control.choices),
-                    ),
+                    f"{self.content_control.choice_count}/{len(self.content_control.choices)}",
                 )
             )
             if self._multiselect:
                 display_message.append(
-                    ("class:fuzzy_info", " (%s)" % len(self.selected_choices))
+                    ("class:fuzzy_info", f" ({len(self.selected_choices)})")
                 )
+            if self.content_control._scorer == substr_scorer:
+                display_message.append(("class:fuzzy_info", self._exact_symbol))
         return display_message
 
     def _generate_before_input(self) -> List[Tuple[str, str]]:
